D5880: fsmonitor: rename new verbose config knob

lothiraldan (Boris Feld) phabricator at mercurial-scm.org
Thu Feb 7 12:08:25 EST 2019


lothiraldan updated this revision to Diff 13890.

REPOSITORY
  rHG Mercurial

CHANGES SINCE LAST UPDATE
  https://phab.mercurial-scm.org/D5880?vs=13889&id=13890

REVISION DETAIL
  https://phab.mercurial-scm.org/D5880

AFFECTED FILES
  hgext/fsmonitor/__init__.py

CHANGE DETAILS

diff --git a/hgext/fsmonitor/__init__.py b/hgext/fsmonitor/__init__.py
--- a/hgext/fsmonitor/__init__.py
+++ b/hgext/fsmonitor/__init__.py
@@ -161,7 +161,7 @@
 configitem('fsmonitor', 'blacklistusers',
     default=list,
 )
-configitem('hgwatchman', 'verbose',
+configitem('fsmonitor', 'verbose',
     default=True,
 )
 configitem('experimental', 'fsmonitor.transaction_notify',
@@ -176,12 +176,12 @@
     """Exception handler for Watchman interaction exceptions"""
     if isinstance(ex, watchmanclient.Unavailable):
         # experimental config: hgwatchman.verbose
-        if ex.warn and ui.configbool('hgwatchman', 'verbose'):
+        if ex.warn and ui.configbool('fsmonitor', 'verbose'):
             ui.warn(str(ex) + '\n')
         if ex.invalidate:
             state.invalidate()
-        # experimental config: hgwatchman.verbose
-        if ui.configbool('hgwatchman','verbose'):
+        # experimental config: fsmonitor.verbose
+        if ui.configbool('fsmonitor', 'verbose'):
             ui.log('fsmonitor', 'Watchman unavailable: %s\n', ex.msg)
     else:
         ui.log('fsmonitor', 'Watchman exception: %s\n', ex)



To: lothiraldan, #hg-reviewers
Cc: pulkit, mjpieters, mercurial-devel


More information about the Mercurial-devel mailing list